@@ -13,6 +13,7 @@ spring_unit = ENERGY / (LENGTH ** 2)
 def openmm_refine(pdb_txt, CDR_definitions, spring_constant=10):
     with tempfile.NamedTemporaryFile("wt") as tmp:
         tmp.writelines(pdb_txt)
+        tmp.flush()
         fixer = pdbfixer.PDBFixer(tmp.name)
 
     fixer.findMissingResidues()
@@ -35,6 +36,7 @@ def openmm_refine(pdb_txt, CDR_definitions, spring_constant=10):
         for res in range(rang[0], rang[1] + 1):
             movable.append((chain, res))
 
+    # Keep atoms close to initial prediction
     force = CustomExternalForce("0.5 * k * ((x-x0)^2 + (y-y0)^2 + (z-z0)^2)")
     force.addGlobalParameter("k", spring_constant*spring_unit)
     for p in ["x0", "y0", "z0"]:
